# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"alt": "charts.ipynb",
         "Chart": "charts.ipynb",
         "confusion_matrix": "charts.ipynb",
         "CM": "charts.ipynb",
         "get_console": "logging.ipynb",
         "console": "logging.ipynb",
         "render": "logging.ipynb",
         "logger": "logging.ipynb",
         "Debug": "logging.ipynb",
         "Info": "logging.ipynb",
         "Warn": "logging.ipynb",
         "Excep": "logging.ipynb",
         "reset_logger_width": "logging.ipynb",
         "isnamedtupleinstance": "markups.ipynb",
         "unpack": "markups.ipynb",
         "read_json": "markups.ipynb",
         "write_json": "markups.ipynb",
         "AttrDict": "registry.ipynb",
         "pretty_json": "markups.ipynb",
         "read_yaml": "markups.ipynb",
         "write_yaml": "markups.ipynb",
         "Config": "registry.ipynb",
         "input_to_str": "paths.ipynb",
         "output_to_path": "paths.ipynb",
         "size": "paths.ipynb",
         "extn": "paths.ipynb",
         "Glob": "paths.ipynb",
         "sample": "paths.ipynb",
         "mv": "paths.ipynb",
         "cp": "paths.ipynb",
         "rm": "paths.ipynb",
         "P": "paths.ipynb",
         "P.ls": "paths.ipynb",
         "P.__repr__": "paths.ipynb",
         "isdir": "paths.ipynb",
         "makedir": "paths.ipynb",
         "fname": "paths.ipynb",
         "fname2": "paths.ipynb",
         "stem": "paths.ipynb",
         "stems": "paths.ipynb",
         "parent": "paths.ipynb",
         "find": "paths.ipynb",
         "zip_files": "paths.ipynb",
         "unzip_file": "paths.ipynb",
         "md5": "paths.ipynb",
         "remove_duplicates": "paths.ipynb",
         "readlines": "paths.ipynb",
         "read_lines": "paths.ipynb",
         "writelines": "paths.ipynb",
         "write_lines": "paths.ipynb",
         "rename_batch": "paths.ipynb",
         "dumpdill": "paths.ipynb",
         "loaddill": "paths.ipynb",
         "dill": "paths.ipynb",
         "parse": "registry.ipynb",
         "parse_and_resolve": "registry.ipynb",
         "registry": "registry.ipynb",
         "train_test_split": "sklegos.ipynb",
         "ColumnSelector": "sklegos.ipynb",
         "transform": "sklegos.ipynb",
         "GroupedEstimator": "sklegos.ipynb",
         "GroupedPredictor": "sklegos.ipynb",
         "EstimatorTransformer": "sklegos.ipynb",
         "MakeFrame": "sklegos.ipynb",
         "ImputeMissingValues": "sklegos.ipynb",
         "LambdaTransformer": "sklegos.ipynb",
         "Cat2Num": "sklegos.ipynb",
         "SplitDateColumn": "sklegos.ipynb"}

modules = ["charts.py",
           "logger.py",
           "markup.py",
           "paths.py",
           "registry.py",
           "sklegos.py"]

doc_url = "https://sizhky.github.io/torch_snippets/"

git_url = "https://github.com/sizhky/torch_snippets/tree/master/"

def custom_doc_links(name): return None
