# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/registry.ipynb (unless otherwise specified).

__all__ = ['parse', 'parse_and_resolve', 'Config', 'AttrDict', 'registry', 'parse', 'parse_and_resolve']

# Cell
from .markup import Config, AttrDict
from .thinc_parser.parser import registry
Config = Config
AttrDict = AttrDict
registry = registry

def parse(file):
    return AttrDict(Config().from_disk(file))

def parse_and_resolve(file):
    return AttrDict(registry.resolve(Config().from_disk(file)))

# Cell
def parse(file):
    return AttrDict(Config().from_disk(file))

def parse_and_resolve(file):
    return AttrDict(registry.resolve(Config().from_disk(file)))